.. _tutorials:



Distributed ML training tutorials
=================================

Here you can find a collection of tutorials for distributing Tensorflow and PyTorch based workflows.

Distributed ML with TensorFlow
------------------------------

.. toctree::
   :maxdepth: 1
   :numbered:

   tf_tutorial_0_basics
   tf_tutorial_1_imagenet
   tf_scaling_test



Distributed ML with PyTorch
---------------------------

.. toctree::
   :maxdepth: 1
   :numbered:

   torch_tutorial_0_basics
   torch_tutorial_1_mnist
   torch_scaling_test



ML workflow tutorials
=====================

Here you can find a collection of tutorials for various complexity ML workflows.


.. toctree::
   :maxdepth: 1
   :numbered:

   basic_comp
   basic_workflow
   intermediate_workflow
   advanced_workflow


   